@@ -44,6 +44,8 @@ class OrderDetailsProxy(VTIXyProxyView):
             raise Http404
 
         response = super(OrderDetailsProxy, self).get(request, *args, **kwargs)
+        if not response.data.get('transaction_id', None):
+            return response
 
         transaction_parts = response.data['transaction_id'].split('.')
         order_is_sold = response.data['sold']
